@@ -19,7 +19,7 @@ class AbstractGeneratorXml(object):
     __metaclass__ = ABCMeta
 
     def __init__(self, data):
-        self.data = data.get('data')
+        self.data = data
         self.dir_xml = os.path.dirname(os.path.abspath(__file__))
         self.dom = parse(self.dir_xml + '/comprobante.xml')
         self.algoritmoSha = None
